# Solcast-PVSolar API 
<em>Used with HA Solcast Integration</em>


[![Publish 📦 to PyPI](https://github.com/oziee/solcast-pvsolar/actions/workflows/publish-to-pypi.yml/badge.svg)](https://github.com/oziee/solcast-pvsolar/actions/workflows/publish-to-pypi.yml) 